@@ -12,11 +12,10 @@ import unicodecsv
 
 import datetime as dt
 
-from billy import db
-from billy.conf import settings, base_arg_parser
-from billy.scrape import (ScrapeError, JSONDateEncoder, get_scraper,
-                          check_sessions)
-from billy.utils import configure_logging, term_for_session
+from billy.core import db
+from billy.core import settings, base_arg_parser
+from billy.scrape import ScrapeError, get_scraper, check_sessions
+from billy.utils import term_for_session, JSONEncoderPlus
 from billy.scrape.validator import DatetimeValidator
 
 
@@ -95,6 +94,12 @@ def _run_scraper(scraper_type, options, metadata):
         else:
             scraper.scrape(time, chambers=options.chambers)
 
+        # error out if events or votes don't scrape anything
+        if not scraper.object_count and scraper_type not in ('events',
+                                                             'votes'):
+            raise ScrapeError("%s scraper didn't save any objects" %
+                              scraper_type)
+
         if scraper_type == 'events' and len(options.chambers) == 2:
             scraper.scrape('other', time)
 
@@ -160,15 +165,15 @@ def _do_imports(abbrev, args):
                 import_committees(abbrev, settings.BILLY_DATA_DIR)
 
     if 'events' in args.types:
-        report['events'] = \
-                import_events(abbrev, settings.BILLY_DATA_DIR)
+        report['events'] = import_events(abbrev, settings.BILLY_DATA_DIR)
 
     return report
 
 
 def _do_reports(abbrev, args):
-    from billy import db
+    from billy.core import db
     from billy.reports.bills import bill_report
+    from billy.reports.votes import vote_report
     from billy.reports.legislators import legislator_report
     from billy.reports.committees import committee_report
 
@@ -180,13 +185,14 @@ def _do_reports(abbrev, args):
         report['legislators'] = legislator_report(abbrev)
     if 'bills' in args.types:
         report['bills'] = bill_report(abbrev)
+        report['votes'] = vote_report(abbrev)
     if 'committees' in args.types:
         report['committees'] = committee_report(abbrev)
 
     db.reports.save(report, safe=True)
 
 
-def main(old_scrape_compat=False):
+def main():
     try:
         parser = argparse.ArgumentParser(
           description='update billy data',
@@ -249,14 +255,6 @@ def main(old_scrape_compat=False):
         settings.update(module_settings)
         settings.update(args)
 
-        configure_logging(args.module)
-
-        # configure oyster
-        if settings.ENABLE_OYSTER:
-            from oyster.conf import settings as oyster_settings
-            oyster_settings.DOCUMENT_CLASSES[args.module + ':billtext'] = \
-                    module.document_class
-
         # make output dir
         args.output_dir = os.path.join(settings.BILLY_DATA_DIR, abbrev)
 
@@ -287,10 +285,7 @@ def main(old_scrape_compat=False):
             args.chambers = ['upper', 'lower']
 
         if not args.actions:
-            if old_scrape_compat:
-                args.actions = ['scrape']
-            else:
-                args.actions = ['scrape', 'import', 'report']
+            args.actions = ['scrape', 'import', 'report']
 
         if not args.types:
             args.types = ['bills', 'legislators', 'votes', 'committees',
@@ -331,7 +326,7 @@ def main(old_scrape_compat=False):
 
             with open(os.path.join(args.output_dir, 'metadata.json'),
                       'w') as f:
-                json.dump(metadata, f, cls=JSONDateEncoder)
+                json.dump(metadata, f, cls=JSONEncoderPlus)
 
             run_record = []
             exec_record = {
@@ -411,8 +406,5 @@ def main(old_scrape_compat=False):
         sys.exit(1)
 
 
-def scrape_compat_main():
-    main(True)
-
 if __name__ == '__main__':
     main()
