@@ -2,27 +2,22 @@ import argparse
 import logging
 import importlib
 
-from billy.conf import settings, base_arg_parser
-from billy.utils import configure_logging
+from billy.core import settings, base_arg_parser
 from billy.commands import BaseCommand
 
 logger = logging.getLogger('billy')
-configure_logging()
 
 COMMAND_MODULES = (
     # lots of these commands can go away as billy matures
-    'billy.commands.serve',             # useful for development
     'billy.commands.textextract',       # useful for development
     'billy.commands.download_photos',
     'billy.commands.dump',
     'billy.commands.update_external_ids',
     'billy.commands.update_leg_ids',
     'billy.commands.validate_api',
+    'billy.commands.sync_versions',
 )
 
-if settings.ENABLE_OYSTER:
-    COMMAND_MODULES += ('billy.commands.oysterize',)
-
 
 def import_command_module(mod):
     try:
@@ -49,7 +44,6 @@ def main():
     # parse arguments, update settings, then run the appropriate function
     args = parser.parse_args()
     settings.update(args)
-    configure_logging(args.subcommand)
     subcommands[args.subcommand].handle(args)
 
 if __name__ == '__main__':
