@@ -6,8 +6,8 @@ import boto
 from boto.s3.key import Key
 import scrapelib
 
-from billy import db
-from billy.conf import settings
+from billy.core import db
+from billy.core import settings
 from billy.commands import BaseCommand
 
 scraper = scrapelib.Scraper(follow_robots=False)
@@ -77,19 +77,25 @@ class DownloadPhotos(BaseCommand):
                 except Exception:
                     continue
 
-                # original size, standardized filenames
-                fname = os.path.join(orig_dir, '{0}.jpg'.format(leg['_id']))
-                subprocess.check_call(['convert', tmpname, fname])
-                _upload(fname, bucket)
+                try:
+                    # original size, standardized filenames
+                    fname = os.path.join(orig_dir,
+                                         '{0}.jpg'.format(leg['_id']))
+                    subprocess.check_call(['convert', tmpname, fname])
+                    _upload(fname, bucket)
 
-                # xsmall - 50x70
-                fname = os.path.join(xsmall_dir, '{0}.jpg'.format(leg['_id']))
-                subprocess.check_call(['convert', tmpname, '-resize',
-                                       '50x75', fname])
-                _upload(fname, bucket)
+                    # xsmall - 50x70
+                    fname = os.path.join(xsmall_dir,
+                                         '{0}.jpg'.format(leg['_id']))
+                    subprocess.check_call(['convert', tmpname, '-resize',
+                                           '50x75', fname])
+                    _upload(fname, bucket)
 
-                # small - 150x200
-                fname = os.path.join(small_dir, '{0}.jpg'.format(leg['_id']))
-                subprocess.check_call(['convert', tmpname, '-resize',
-                                       '150x200', fname])
-                _upload(fname, bucket)
+                    # small - 150x200
+                    fname = os.path.join(small_dir,
+                                         '{0}.jpg'.format(leg['_id']))
+                    subprocess.check_call(['convert', tmpname, '-resize',
+                                           '150x200', fname])
+                    _upload(fname, bucket)
+                except subprocess.CalledProcessError:
+                    print 'convert failed for ', fname
