@@ -2,7 +2,7 @@ import sys
 import urllib2
 import importlib
 
-from billy.conf import settings
+from billy.core import settings
 from billy.commands import BaseCommand
 
 
