@@ -1,8 +1,9 @@
-from billy import db
+from billy.core import db
 from billy.commands import BaseCommand
 from billy.utils import metadata
-from billy.importers.names import NameMatcher
-from billy.conf import settings
+from billy.importers.names import get_legislator_id
+from billy.importers.bills import match_sponsor_ids
+from billy.core import settings
 
 
 class UpdateLegIds(BaseCommand):
@@ -14,8 +15,6 @@ class UpdateLegIds(BaseCommand):
         self.add_argument('term', help='term to run matching for')
 
     def handle(self, args):
-        nm = NameMatcher(args.abbr, args.term)
-
         for t in metadata(args.abbr)['terms']:
             if t['name'] == args.term:
                 sessions = t['sessions']
@@ -29,14 +28,19 @@ class UpdateLegIds(BaseCommand):
                                    'session': session})
 
             for bill in bills:
-                for sponsor in bill['sponsors']:
-                    if not sponsor['leg_id']:
-                        sponsor['leg_id'] = nm.match(sponsor['name'],
-                                                     bill['chamber'])
-                for vote in bill['votes']:
-                    for type in ('yes_votes', 'no_votes', 'other_votes'):
-                        for voter in vote[type]:
-                            if not voter['leg_id']:
-                                voter['leg_id'] = nm.match(voter['name'],
-                                                           vote['chamber'])
+                match_sponsor_ids(args.abbr, bill)
                 db.bills.save(bill, safe=True)
+
+            votes = db.votes.find({settings.LEVEL_FIELD: args.abbr,
+                                   'session': session})
+            for vote in votes:
+                vote['_voters'] = []
+                for type in ('yes_votes', 'no_votes', 'other_votes'):
+                    for voter in vote[type]:
+                        voter['leg_id'] = get_legislator_id(args.abbr,
+                                                            vote['session'],
+                                                            vote['chamber'],
+                                                            voter['name'])
+                        if voter['leg_id']:
+                            vote['_voters'].append(voter['leg_id'])
+                db.votes.save(vote, safe=True)
