@@ -2,9 +2,9 @@ import os
 import json
 import random
 
-from billy import db
+from billy.core import db
 from billy.commands import BaseCommand
-from billy.conf import settings
+from billy.core import settings
 
 from billy.commands.dump import APIValidator, api_url
 
