@@ -6,17 +6,15 @@ import datetime
 from time import time
 from collections import defaultdict
 
-from billy import db
-from billy.conf import settings
-from billy.scrape import JSONDateEncoder
-from billy.utils import metadata, term_for_session
+from billy.core import settings, db
+from billy.utils import (metadata, term_for_session, fix_bill_id,
+                         JSONEncoderPlus)
 from billy.importers.names import get_legislator_id
 from billy.importers.filters import apply_filters
 
 from billy.importers.subjects import SubjectCategorizer
 from billy.importers.utils import (insert_with_id, update, prepare_obj,
-                                   next_big_id, oysterize, fix_bill_id,
-                                   get_committee_id)
+                                   next_big_id, get_committee_id)
 
 if hasattr(settings, "ENABLE_GIT") and settings.ENABLE_GIT:
     from dulwich.repo import Repo
@@ -69,14 +67,32 @@ def ensure_indexes():
                            ('action_dates.passed_lower', pymongo.DESCENDING)])
 
     # votes index
+    db.votes.ensure_index([('bill_id', pymongo.ASCENDING),
+                           ('date', pymongo.ASCENDING)])
     db.votes.ensure_index([('_voters', pymongo.ASCENDING),
                            ('date', pymongo.ASCENDING)])
 
     # subjects index
     db.subjects.ensure_index('abbr')
+    db.manual.name_matchers.ensure_index('abbr')
 
 
-def import_votes(data_dir):
+def match_sponsor_ids(abbr, bill):
+    for sponsor in bill['sponsors']:
+        # use sponsor's chamber if specified
+        sponsor['leg_id'] = get_legislator_id(abbr, bill['session'],
+                                              sponsor.get('chamber',
+                                                          bill['chamber']),
+                                              sponsor['name'])
+        if sponsor['leg_id'] is None:
+            sponsor['leg_id'] = get_legislator_id(abbr, bill['session'], None,
+                                                  sponsor['name'])
+        if sponsor['leg_id'] is None:
+            sponsor['committee_id'] = get_committee_id(abbr, bill['chamber'],
+                                                       sponsor['name'])
+
+
+def load_standalone_votes(data_dir):
     pattern = os.path.join(data_dir, 'votes', '*.json')
     paths = glob.glob(pattern)
 
@@ -110,10 +126,7 @@ def git_add_bill(data):
     global git_active_tree
     global git_active_commit
 
-    bill = json.dumps(data,
-                      cls=JSONDateEncoder,
-                      sort_keys=True,
-                      indent=4)
+    bill = json.dumps(data, cls=JSONEncoderPlus, sort_keys=True, indent=4)
     spam = Blob.from_string(bill)
     bid = str(data['_id'])
     git_active_repo.object_store.add_object(spam)
@@ -207,22 +220,31 @@ def git_prelod(abbr):
     git_active_tree = tree
 
 
-def oysterize_version(bill, version):
-    titles = [bill['title']] + bill.get('alternate_titles', [])
-    logger.info('{0} tracked in oyster'.format(version['doc_id']))
-    oysterize(version['url'], bill[settings.LEVEL_FIELD] + ':billtext',
-              id=version['doc_id'],
-              # metadata
-              mimetype=version.get('mimetype', None),
-              titles=titles,
-              state=bill['state'], session=bill['session'],
-              chamber=bill['chamber'], bill_id=bill['bill_id'],
-              subjects=bill.get('subjects', []),
-              sponsors=[s['leg_id'] for s in bill['sponsors']],
-             )
+def track_version(bill, version):
+    doc = {'titles': [bill['title']] + bill.get('alternate_titles', []),
+           'url': version['url'],
+           'type': 'version',
+           'mimetype': version.get('mimetype', None),
+           'state': bill['state'],
+           'session': bill['session'],
+           'chamber': bill['chamber'],
+           'bill_id': bill['bill_id'],
+           'subjects': bill.get('subjects', []),
+           'sponsors': [s['leg_id'] for s in bill['sponsors'] if s['leg_id']]
+          }
+    # insert or update this document
+    db.tracked_versions.update({'_id': version['doc_id']}, {'$set': doc},
+                               upsert=True)
 
 
-def import_bill(data, votes, categorizer):
+def import_bill(data, standalone_votes, categorizer):
+    """
+        insert or update a bill
+
+        data - raw bill JSON
+        standalone_votes - votes scraped separately
+        categorizer - SubjectCategorizer (None - no categorization)
+    """
     abbr = data[settings.LEVEL_FIELD]
 
     # clean up bill_ids
@@ -243,22 +265,6 @@ def import_bill(data, votes, categorizer):
     if categorizer:
         categorizer.categorize_bill(data)
 
-    # this is a hack initially added for Rhode Island where we can't
-    # determine the full bill_id, if this key is in the metadata
-    # we just use the numeric portion, not ideal as it won't work
-    # where HB/SBs overlap, but in RI they never do
-    if metadata(abbr).get('_partial_vote_bill_id'):
-        # pull off numeric portion of bill_id
-        numeric_bill_id = data['bill_id'].split()[1]
-        bill_votes = votes.pop((data['chamber'], data['session'],
-                                numeric_bill_id), [])
-    else:
-        # add loaded votes to data
-        bill_votes = votes.pop((data['chamber'], data['session'],
-                                data['bill_id']), [])
-
-    data['votes'].extend(bill_votes)
-
     # companions
     for companion in data['companions']:
         companion['bill_id'] = fix_bill_id(companion['bill_id'])
@@ -274,51 +280,49 @@ def import_bill(data, votes, categorizer):
             logger.warning('Unknown companion: {chamber} {session} {bill_id}'
                            .format(**companion))
 
+    # look for a prior version of this bill
     bill = db.bills.find_one({settings.LEVEL_FIELD: abbr,
                               'session': data['session'],
                               'chamber': data['chamber'],
                               'bill_id': data['bill_id']})
 
-    # keep vote/doc ids consistent
-    vote_matcher = VoteMatcher(abbr)
+    # keep doc ids consistent
     doc_matcher = DocumentMatcher(abbr)
     if bill:
-        vote_matcher.learn_ids(bill['votes'])
         doc_matcher.learn_ids(bill['versions'] + bill['documents'])
-    vote_matcher.set_ids(data['votes'])
     doc_matcher.set_ids(data['versions'] + data['documents'])
 
     # match sponsor leg_ids
-    for sponsor in data['sponsors']:
-        # use sponsor's chamber if specified
-        id = get_legislator_id(abbr, data['session'], sponsor.get('chamber'),
-                               sponsor['name'])
-        sponsor['leg_id'] = id
-        if id is None:
-            cid = get_committee_id(abbr, data['chamber'], sponsor['name'])
-            if not cid is None:
-                sponsor['committee_id'] = cid
+    match_sponsor_ids(abbr, data)
 
-    # process votes
-    for vote in data['votes']:
+    # process votes ############
 
-        # committee_ids
-        if 'committee' in vote:
-            committee_id = get_committee_id(abbr, vote['chamber'],
-                                            vote['committee'])
-            vote['committee_id'] = committee_id
+    # pull votes off bill
+    bill_votes = data.pop('votes', [])
 
-        # vote leg_ids
-        for vtype in ('yes_votes', 'no_votes', 'other_votes'):
-            svlist = []
-            for svote in vote[vtype]:
-                id = get_legislator_id(abbr, data['session'],
-                                       vote['chamber'], svote)
-                svlist.append({'name': svote, 'leg_id': id})
+    # grab the external bill votes if present
+    if metadata(abbr).get('_partial_vote_bill_id'):
+        # this is a hack initially added for Rhode Island where we can't
+        # determine the full bill_id, if this key is in the metadata
+        # we just use the numeric portion, not ideal as it won't work
+        # where HB/SBs overlap, but in RI they never do
+        # pull off numeric portion of bill_id
+        numeric_bill_id = data['bill_id'].split()[1]
+        bill_votes += standalone_votes.pop((data['chamber'], data['session'],
+                                            numeric_bill_id), [])
+    else:
+        # add loaded votes to data
+        bill_votes += standalone_votes.pop((data['chamber'], data['session'],
+                                            data['bill_id']), [])
 
-            vote[vtype] = svlist
+    # do id matching and other vote prep
+    if bill:
+        prepare_votes(abbr, data['session'], bill['_id'], bill_votes)
+    else:
+        prepare_votes(abbr, data['session'], None, bill_votes)
+
+    # process actions ###########
 
-    # process actions
     dates = {'first': None, 'last': None, 'passed_upper': None,
              'passed_lower': None, 'signed': None}
 
@@ -384,9 +388,11 @@ def import_bill(data, votes, categorizer):
 
         # vote-action matching
         action_attached = False
-        if set(action['type']).intersection(vote_flags):
-            for vote in data['votes']:
-                if not vote['date'] or not action['date']:
+        # only attempt vote matching if action has a date and is one of the
+        # designated vote action types
+        if set(action['type']).intersection(vote_flags) and action['date']:
+            for vote in bill_votes:
+                if not vote['date']:
                     continue
 
                 delta = abs(vote['date'] - action['date'])
@@ -394,8 +400,7 @@ def import_bill(data, votes, categorizer):
                     vote['chamber'] == action['actor']):
                     if action_attached:
                         # multiple votes match, we can't guess
-                        if "related_votes" in action:
-                            del(action['related_votes'])
+                        action.pop('related_votes', None)
                     else:
                         related_vote = vote['vote_id']
                         if related_vote in already_linked:
@@ -408,7 +413,7 @@ def import_bill(data, votes, categorizer):
     # remove related_votes that we linked to multiple actions
     for action in data['actions']:
         for vote in remove_vote:
-            if "related_votes" in action and vote in action['related_votes']:
+            if vote in action.get('related_votes', []):
                 action['related_votes'].remove(vote)
 
     # save action dates to data
@@ -419,9 +424,8 @@ def import_bill(data, votes, categorizer):
     alt_titles = set(data.get('alternate_titles', []))
 
     for version in data['versions']:
-        # push versions to oyster
-        if settings.ENABLE_OYSTER and 'url' in version:
-            oysterize_version(data, version)
+        # add/update tracked_versions collection
+        track_version(data, version)
 
         # Merge any version titles into the alternate_titles list
         if 'title' in version:
@@ -438,16 +442,14 @@ def import_bill(data, votes, categorizer):
     data = apply_filters(filters, data)
 
     if not bill:
-        bill_id = insert_with_id(data)
+        insert_with_id(data)
         git_add_bill(data)
-
-        denormalize_votes(data, bill_id)
+        save_votes(data, bill_votes)
         return "insert"
     else:
-        git_add_bill(bill)
-
         update(bill, data, db.bills)
-        denormalize_votes(bill, bill['_id'])
+        git_add_bill(bill)
+        save_votes(bill, bill_votes)
         return "update"
 
 
@@ -463,7 +465,7 @@ def import_bills(abbr, data_dir):
         "total": 0
     }
 
-    votes = import_votes(data_dir)
+    votes = load_standalone_votes(data_dir)
     try:
         categorizer = SubjectCategorizer(abbr)
     except Exception as e:
@@ -517,19 +519,52 @@ def populate_current_fields(abbr):
         db.bills.save(bill, safe=True)
 
 
-def denormalize_votes(bill, bill_id):
-    # remove all existing votes for this bill
-    db.votes.remove({'bill_id': bill_id}, safe=True)
+def prepare_votes(abbr, session, bill_id, scraped_votes):
+    # if bill already exists, try and preserve vote_ids
+    vote_matcher = VoteMatcher(abbr)
 
-    # add votes
-    for vote in bill.get('votes', []):
-        vote = vote.copy()
+    if bill_id:
+        existing_votes = list(db.votes.find({'bill_id': bill_id}))
+        if existing_votes:
+            vote_matcher.learn_ids(existing_votes)
+
+    vote_matcher.set_ids(scraped_votes)
+
+    # link votes to committees and legislators
+    for vote in scraped_votes:
+
+        # committee_ids
+        if 'committee' in vote:
+            committee_id = get_committee_id(abbr, vote['chamber'],
+                                            vote['committee'])
+            vote['committee_id'] = committee_id
+
+        # vote leg_ids
+        vote['_voters'] = []
+        for vtype in ('yes_votes', 'no_votes', 'other_votes'):
+            svlist = []
+            for svote in vote[vtype]:
+                id = get_legislator_id(abbr, session, vote['chamber'], svote)
+                svlist.append({'name': svote, 'leg_id': id})
+                vote['_voters'].append(id)
+
+            vote[vtype] = svlist
+
+
+def save_votes(bill, votes):
+    # doesn't delete votes if none were scraped this time
+    if not votes:
+        return
+
+    # remove all existing votes for this bill
+    db.votes.remove({'bill_id': bill['_id']}, safe=True)
+
+    # save the votes
+    for vote in votes:
         vote['_id'] = vote['vote_id']
-        vote['bill_id'] = bill_id
+        vote['bill_id'] = bill['_id']
         vote[settings.LEVEL_FIELD] = bill[settings.LEVEL_FIELD]
-        vote['_voters'] = [l['leg_id'] for l in vote['yes_votes']]
-        vote['_voters'] += [l['leg_id'] for l in vote['no_votes']]
-        vote['_voters'] += [l['leg_id'] for l in vote['other_votes']]
+        vote['session'] = bill['session']
         db.votes.save(vote, safe=True)
 
 
