@@ -5,8 +5,8 @@ import datetime
 import json
 import logging
 
-from billy import db
-from billy.conf import settings
+from billy.core import db
+from billy.core import settings
 from billy.importers.utils import insert_with_id, update, prepare_obj
 from billy.importers.filters import apply_filters
 
@@ -169,7 +169,7 @@ def import_legislator(data):
 
         if leg:
             if 'old_roles' not in data:
-                data['old_roles'] = {}
+                data['old_roles'] = leg.get('old_roles', {})
              # put scraped roles into their old_roles
             data['old_roles'][scraped_term] = data['roles']
             data['roles'] = leg['roles']  # don't overwrite their current roles
@@ -183,7 +183,7 @@ def import_legislator(data):
              'roles': {'$elemMatch': spec}})
         if leg:
             if 'old_roles' not in data:
-                data['old_roles'] = {}
+                data['old_roles'] = leg.get('old_roles', {})
 
             # scraped_term < leg's term
             if term_older_than(abbr, scraped_term, leg['roles'][0]['term']):
