@@ -9,16 +9,8 @@ from bson.son import SON
 import pymongo.errors
 import name_tools
 
-from billy import db
-from billy.conf import settings
-
-if settings.ENABLE_OYSTER:
-    oyster_import_exception = None
-    try:
-        from oyster.core import kernel
-    except ImportError as e:
-        kernel = None               # noqa
-        oyster_import_exception = e
+from billy.core import db, settings
+from billy.importers.names import attempt_committee_match
 
 
 def _get_property_dict(schema):
@@ -31,15 +23,6 @@ def _get_property_dict(schema):
     return pdict
 
 
-# fixing bill ids
-_bill_id_re = re.compile(r'([A-Z]*)\s*0*([-\d]+)')
-
-
-def fix_bill_id(bill_id):
-    bill_id = bill_id.replace('.', '')
-    return _bill_id_re.sub(r'\1 \2', bill_id).strip()
-
-
 # load standard fields from schema files
 standard_fields = {}
 for _type in ('bill', 'person', 'committee', 'metadata', 'vote', 'event'):
@@ -114,6 +97,7 @@ def _timestamp_to_dt(timestamp):
 def compare_committee(ctty1, ctty2):
     def _cleanup(obj):
         ctty_junk_words = [
+            "(\s+|^)standing(\s+|$)",
             "(\s+|^)committee(\s+|$)",
             "(\s+|^)on(\s+|$)",
             "(\s+|^)joint(\s+|$)",
@@ -157,10 +141,6 @@ def update(old, new, collection, sneaky_update_filter=None):
             format is a dict mapping field names to a comparison function
             that returns True iff there is a change
     """
-    # To prevent deleting standalone votes..
-    if 'votes' in new and not new['votes']:
-        del new['votes']
-
     # need_save = something has changed
     need_save = False
 
@@ -365,6 +345,14 @@ __committee_ids = {}
 
 
 def get_committee_id(abbr, chamber, committee):
+
+    manual = attempt_committee_match(abbr,
+                                     chamber,
+                                     committee)
+
+    if manual:
+        return manual
+
     key = (abbr, chamber, committee)
     if key in __committee_ids:
         return __committee_ids[key]
@@ -412,10 +400,3 @@ def get_committee_id_alt(abbr, name, chamber):
         matched_committee = get_committee_id_alt(abbr, name, None)
 
     return matched_committee
-
-
-def oysterize(url, doc_class, id, **kwargs):
-    if not kernel:
-        raise oyster_import_exception
-    # kwargs pass through as metadata
-    kernel.track_url(url, doc_class, id=id, **kwargs)
