@@ -1,23 +1,20 @@
+import re
 import math
 import operator
 import collections
 import itertools
 
 from django.core import urlresolvers
-import pyes
 import pymongo
+import pyes
 
-from billy.conf import settings
-from billy.utils import parse_param_dt
-
-from .base import (db, Document, RelatedDocument, RelatedDocuments,
+from billy.utils import parse_param_dt, fix_bill_id
+from billy.core import mdb as db, settings, elasticsearch
+from .base import (Document, RelatedDocument, RelatedDocuments,
                    ListManager, AttrManager, take)
 from .metadata import Metadata
 from .utils import CachedAttribute, mongoid_2_url
 
-elasticsearch = pyes.ES(settings.ELASTICSEARCH_HOST,
-                        settings.ELASTICSEARCH_TIMEOUT)
-
 
 class Sponsor(dict):
     legislator = RelatedDocument('Legislator', instance_key='leg_id')
@@ -119,7 +116,13 @@ class Action(dict):
         if 'related_entities' in self:
             for entity in self['related_entities']:
                 name = entity['name']
-                url = mongoid_2_url(state, entity['id'])
+                _id = entity['id']
+
+                # If the importer couldn't ID the entity,
+                # skip.
+                if _id is None:
+                    continue
+                url = mongoid_2_url(state, _id)
                 link = '<a href="%s">%s</a>' % (url, name)
                 if name in action:
                     action = action.replace(entity['name'], link)
@@ -211,15 +214,17 @@ class BillVote(Document):
         ids = []
         for k in ('yes', 'no', 'other'):
             ids.extend(map(id_getter, self[k + '_votes']))
-        objs = db.legislators.find({'_id': {'$in': ids}}, **kwargs)
+        objs = db.legislators.find({'_all_ids': {'$in': ids}}, **kwargs)
 
         # Handy to keep a reference to the vote on each legislator.
         objs = list(objs)
+        id_cache = {}
         for obj in objs:
             obj.vote = self
-        objs = dict((obj['_id'], obj) for obj in objs)
+            for _id in obj['_all_ids']:
+                id_cache[_id] = obj
 
-        return objs
+        return id_cache
 
     @CachedAttribute
     def legislator_vote_value(self):
@@ -239,9 +244,16 @@ class BillVote(Document):
     def _vote_legislators(self, yes_no_other):
         '''Return all legislators who votes yes/no/other on this bill.
         '''
-        id_getter = operator.itemgetter('leg_id')
-        ids = map(id_getter, self['%s_votes' % yes_no_other])
-        return map(self._legislator_objects.get, ids)
+        #id_getter = operator.itemgetter('leg_id')
+        #ids = map(id_getter, self['%s_votes' % yes_no_other])
+        #return map(self._legislator_objects.get, ids)
+        result = []
+        for voter in self[yes_no_other + '_votes']:
+            if voter['leg_id']:
+                result.append(self._legislator_objects.get(voter['leg_id']))
+            else:
+                result.append(voter)
+        return result
 
     def yes_vote_legislators(self):
         return self._vote_legislators('yes')
@@ -253,7 +265,8 @@ class BillVote(Document):
         return self._vote_legislators('other')
 
     def get_absolute_url(self):
-        url = urlresolvers.reverse('vote', args=[self['state'], self['_id']])
+        url = urlresolvers.reverse('vote', args=[self[settings.LEVEL_FIELD],
+                                                 self['_id']])
         return url
 
     @CachedAttribute
@@ -304,12 +317,13 @@ class Bill(Document):
 
     @property
     def metadata(self):
-        return Metadata.get_object(self['state'])
+        return Metadata.get_object(self[settings.LEVEL_FIELD])
 
     def get_absolute_url(self):
         # canonical URL doesn't have spaces
         url = urlresolvers.reverse('bill',
-                                   args=[self['state'], self['session'],
+                                   args=[self[settings.LEVEL_FIELD],
+                                         self['session'],
                                          self['bill_id'].replace(' ', '')])
         return url
 
@@ -317,7 +331,8 @@ class Bill(Document):
         return self['bill_id']
 
     def get_admin_url(self):
-        return urlresolvers.reverse('bill', args=[self['state'], self.id])
+        return urlresolvers.reverse('bill', args=[self[settings.LEVEL_FIELD],
+                                                  self.id])
 
     def session_details(self):
         metadata = self.metadata
@@ -425,7 +440,9 @@ class Bill(Document):
         _filter = {}
         for key, value in [('state', state),
                             ('chamber', chamber),
-                            ('subjects', subjects)]:
+                            ('subjects', subjects),
+                            ('bill_id', bill_id),
+                          ]:
             if value is not None:
                 _filter[key] = value
 
@@ -465,6 +482,17 @@ class Bill(Document):
 
         # process full-text query
         if query:
+            # block spammers, possibly move to a BANNED_SEARCH_LIST setting
+            if '<a href' in query:
+                return db.bills.find({'state': None})
+
+            if re.findall('\d+', query):
+                _id_filter = dict(_filter)
+                _id_filter['bill_id'] = fix_bill_id(query).upper()
+                result = db.bills.find(_id_filter)
+                if result:
+                    return result
+
             query = {"query_string": {"fields": ["text", "title"],
                                       "default_operator": "AND",
                                       "query": query}}
