@@ -2,10 +2,11 @@ import datetime
 import logging
 from collections import defaultdict
 
-from billy import db
-from billy.conf import settings
+from billy.core import db
+from billy.core import settings
 from billy.utils import term_for_session
-from billy.reports.utils import update_common, get_quality_exceptions
+from billy.reports.utils import (update_common, get_quality_exceptions,
+                                 combine_reports)
 
 logger = logging.getLogger('billy')
 
@@ -27,19 +28,12 @@ def _bill_report_dict():
             '_sponsor_count': 0,
             '_sponsors_with_id_count': 0,
             'sponsors_per_type': defaultdict(int),
-            'vote_count': 0,
-            '_passed_vote_count': 0,
-            'votes_per_month': defaultdict(int),
-            'votes_per_chamber': defaultdict(int),
-            'votes_per_type': defaultdict(int),
-            'bad_vote_counts': set(),
-            '_rollcall_count': 0,
-            '_rollcalls_with_leg_id_count': 0,
             '_subjects_count': 0,
             'bills_per_subject': defaultdict(int),
             'versionless_count': 0,
             'version_count': 0,
-            'unmatched_leg_ids': set(),
+            'unmatched_sponsors': set(),
+            'progress_meter_gaps': set(),
            }
 
 
@@ -93,8 +87,8 @@ def scan_bills(abbr):
             if sponsor.get('leg_id') or sponsor.get('committee_id'):
                 session_d['_sponsors_with_id_count'] += 1
             else:
-                # keep missing leg_ids
-                session_d['unmatched_leg_ids'].add(
+                # keep list of unmatched sponsors
+                session_d['unmatched_sponsors'].add(
                     (term_for_session(abbr, bill['session']), bill['chamber'],
                     sponsor['name'])
                 )
@@ -107,52 +101,6 @@ def scan_bills(abbr):
             else:
                 quality_exceptions['bills:no_sponsors'].remove(bill['_id'])
 
-        # votes
-        for vote in bill['votes']:
-            session_d['vote_count'] += 1
-            if vote['passed']:
-                session_d['_passed_vote_count'] += 1
-            session_d['votes_per_chamber'][vote['chamber']] += 1
-            if not vote.get('type'):
-                logger.warning('vote is missing type on %s' % bill['_id'])
-                continue
-            session_d['votes_per_type'][vote.get('type')] += 1
-            if not vote.get('date'):
-                logger.warning('vote is missing date on %s' % bill['_id'])
-                continue
-            session_d['votes_per_month'][vote['date'].strftime('%Y-%m')] += 1
-
-            # roll calls
-            has_rollcalls = False
-            for rc in (vote['yes_votes'] + vote['no_votes'] +
-                       vote['other_votes']):
-                has_rollcalls = True
-                session_d['_rollcall_count'] += 1
-                if rc.get('leg_id'):
-                    session_d['_rollcalls_with_leg_id_count'] += 1
-                else:
-                    # keep missing leg_ids
-                    session_d['unmatched_leg_ids'].add(
-                        (term_for_session(abbr, bill['session']),
-                         vote['chamber'],
-                        rc['name'])
-                    )
-
-            # check counts if any rollcalls are present
-            if has_rollcalls:
-                if (len(vote['yes_votes']) != vote['yes_count'] and
-                    vote['vote_id'] not in
-                    quality_exceptions['votes:bad_yes_count']):
-                    session_d['bad_vote_counts'].add(vote['vote_id'])
-                if (len(vote['no_votes']) != vote['no_count'] and
-                    vote['vote_id'] not in
-                    quality_exceptions['votes:bad_no_count']):
-                    session_d['bad_vote_counts'].add(vote['vote_id'])
-                if (len(vote['other_votes']) != vote['other_count'] and
-                    vote['vote_id'] not in
-                    quality_exceptions['votes:bad_other_count']):
-                    session_d['bad_vote_counts'].add(vote['vote_id'])
-
         # subjects
         for subj in bill.get('scraped_subjects', []):
             uncategorized_subjects[subj] += 1
@@ -179,6 +127,31 @@ def scan_bills(abbr):
             duplicate_versions[doc['url']] += 1
         # TODO: add duplicate document detection back in?
 
+        # Check for progress meter gaps.
+        progress_meter_gaps = session_d['progress_meter_gaps']
+        action_dates = bill['action_dates']
+        bill_chamber = bill['chamber']
+        other_chamber = dict(lower='upper', upper='lower')[bill_chamber]
+
+        # Check for bills that were signed but didn't pass both chambers.
+        if bill['type'] == 'bill':
+            if action_dates['signed']:
+                if not action_dates['passed_upper']:
+                    progress_meter_gaps.add(bill['_id'])
+                elif not action_dates['passed_lower']:
+                    progress_meter_gaps.add(bill['_id'])
+
+        else:
+            # Check for nonbills that were signed but didn't pass their
+            # house of origin.
+            if action_dates['signed']:
+                if not action_dates['passed_' + bill_chamber]:
+                    progress_meter_gaps.add(bill['_id'])
+
+        if action_dates['passed_' + other_chamber]:
+            if not action_dates['passed_' + bill_chamber]:
+                progress_meter_gaps.add(bill['_id'])
+
     dup_version_urls = []
     dup_source_urls = []
     for url, n in duplicate_versions.iteritems():
@@ -199,31 +172,10 @@ def scan_bills(abbr):
             'other_actions': other_actions.items(),
             'uncategorized_subjects': uncategorized_subjects.items(),
             'sessions': sessions,
+            'progress_meter_gaps': [],
            }
 
 
-def combine_bill_reports(reports):
-    report = _bill_report_dict()
-
-    for session in reports.itervalues():
-        # go over all report fields
-        # integers are summed, sets are combined, and dicts summed by key
-        for field, value in report.iteritems():
-            if isinstance(value, int):
-                report[field] += session[field]
-            elif isinstance(value, set):
-                report[field].update(session[field])
-                session[field] = list(session[field])
-            elif isinstance(value, defaultdict):
-                for k, v in session[field].iteritems():
-                    report[field][k] += v
-
-    for field, value in report.iteritems():
-        if isinstance(value, set):
-            report[field] = list(value)
-    return report
-
-
 def calculate_percentages(report):
     # general bill stuff
     bill_count = float(report['upper_count'] + report['lower_count']) / 100
@@ -254,26 +206,11 @@ def calculate_percentages(report):
         for k in report['sponsors_per_type'].iterkeys():
             report['sponsors_per_type'][k] /= _sponsor_count
 
-    # votes
-    vote_count = float(report['vote_count']) / 100
-    if vote_count:
-        report['votes_passed'] = report.pop('_passed_vote_count') / vote_count
-        for k in report['votes_per_type'].iterkeys():
-            report['votes_per_type'][k] /= vote_count
-        for k in report['votes_per_chamber'].iterkeys():
-            report['votes_per_chamber'][k] /= vote_count
-        for k in report['votes_per_month'].iterkeys():
-            report['votes_per_month'][k] /= vote_count
-    rollcall_count = float(report.pop('_rollcall_count')) / 100
-    if rollcall_count:
-        report['rollcalls_with_leg_id'] = (
-            report.pop('_rollcalls_with_leg_id_count') / rollcall_count
-        )
-
 
 def bill_report(abbr):
     report = scan_bills(abbr)
-    combined_report = combine_bill_reports(report['sessions'])
+    combined_report = combine_reports(report['sessions'],
+                                           _bill_report_dict())
     for session in report['sessions'].itervalues():
         calculate_percentages(session)
     calculate_percentages(combined_report)
