@@ -1,13 +1,12 @@
 import os
-import time
 import logging
-import datetime
 import importlib
 import json
 
 from billy.scrape.validator import DatetimeValidator
 
-from billy.conf import settings
+from billy.core import settings
+from billy.utils import JSONEncoderPlus
 
 import scrapelib
 
@@ -39,18 +38,6 @@ class NoDataForPeriod(ScrapeError):
         return 'No data exists for %s' % self.period
 
 
-class JSONDateEncoder(json.JSONEncoder):
-    """
-    JSONEncoder that encodes datetime objects as Unix timestamps.
-    """
-    def default(self, obj):
-        if isinstance(obj, datetime.datetime):
-            return time.mktime(obj.utctimetuple())
-        elif isinstance(obj, datetime.date):
-            return time.mktime(obj.timetuple())
-
-        return json.JSONEncoder.default(self, obj)
-
 # maps scraper_type -> scraper
 _scraper_registry = dict()
 
@@ -106,6 +93,7 @@ class Scraper(scrapelib.Scraper):
 
         self.metadata = metadata
         self.output_dir = output_dir
+        self.output_names = set()
 
         # make output_dir
         os.path.isdir(self.output_dir) or os.path.makedirs(self.output_dir)
@@ -119,8 +107,16 @@ class Scraper(scrapelib.Scraper):
         # logging convenience methods
         self.logger = logging.getLogger("billy")
         self.log = self.logger.info
+        self.info = self.logger.info
         self.debug = self.logger.debug
         self.warning = self.logger.warning
+        self.error = self.logger.error
+        self.critical = self.logger.critical
+
+    @property
+    def object_count(self):
+        # number of distinct output filenames
+        return len(self.output_names)
 
     def validate_json(self, obj):
         if not hasattr(self, '_schema'):
@@ -180,9 +176,10 @@ class Scraper(scrapelib.Scraper):
         obj[settings.LEVEL_FIELD] = getattr(self, settings.LEVEL_FIELD)
 
         filename = obj.get_filename()
+        self.output_names.add(filename)     # keep tally of all output names
         with open(os.path.join(self.output_dir, self.scraper_type, filename),
                   'w') as f:
-            json.dump(obj, f, cls=JSONDateEncoder)
+            json.dump(obj, f, cls=JSONEncoderPlus)
 
         # validate after writing, allows for inspection
         self.validate_json(obj)
