@@ -16,9 +16,9 @@ def convert_pdf(filename, type='xml'):
     try:
         pipe = subprocess.Popen(commands[type], stdout=subprocess.PIPE,
                                 close_fds=True).stdout
-    except OSError:
-        raise EnvironmentError("error running %s, missing executable?" %
-                               ' '.join(commands[type]))
+    except OSError as e:
+        raise EnvironmentError("error running %s, missing executable? [%s]" %
+                               ' '.join(commands[type]), e)
     data = pipe.read()
     pipe.close()
     return data
