@@ -1,6 +1,7 @@
-from billy.conf import settings
-# modify the db name upon initial import (this file has to run first)
+from billy.core import settings, _configure_db
 settings.MONGO_DATABASE += '_test'
+_configure_db(settings.MONGO_HOST, settings.MONGO_PORT,
+              settings.MONGO_DATABASE)
 import pymongo
 
 
