@@ -1,21 +1,23 @@
 import copy
-from billy import db
+from billy.core import db
 from billy.importers import bills, names
 
 from nose.tools import with_setup, assert_equal
 
+from .. import fixtures
+
 
 def setup_func():
-    db.metadata.drop()
     db.bills.drop()
+    db.votes.drop()
     db.legislators.drop()
     db.document_ids.drop()
     db.vote_ids.drop()
     db.committees.drop()
     names.__matchers = {}
 
-    db.metadata.insert({'_id': 'ex',
-                        'terms': [{'name': 'T1', 'sessions': ['S1', 'S2']}]})
+    fixtures.load_metadata()
+
     db.legislators.insert({'state': 'ex',
                            '_id': 'EXL000001', 'leg_id': 'EXL000001',
                            'chamber': 'upper',
@@ -110,10 +112,11 @@ def test_import_bill():
     assert bill['sponsors'][0]['leg_id'] == 'EXL000001'
 
     # test vote import
-    assert len(bill['votes']) == 3
-    assert bill['votes'][0]['vote_id'] == 'EXV00000001'
-    assert bill['votes'][0]['yes_votes'][0]['leg_id'] == 'EXL000001'
-    assert 'committee_id' in bill['votes'][1]
+    bill_votes = db.votes.find()
+    assert bill_votes.count() == 3
+    assert bill_votes[0]['vote_id'] == 'EXV00000001'
+    assert bill_votes[0]['yes_votes'][0]['leg_id'] == 'EXL000001'
+    assert 'committee_id' in bill_votes[1]
 
     # test actions
     assert bill['action_dates']['first'] == 1331000000
@@ -146,8 +149,9 @@ def test_import_bill():
     bill = db.bills.find_one('EXB00000002')
 
     # votes haven't changed, versions, titles, and sponsors have
-    assert len(bill['votes']) == 3
-    assert bill['votes'][0]['vote_id'] == 'EXV00000001'
+    bill_votes = db.votes.find()
+    assert bill_votes.count() == 3
+    assert bill_votes[0]['vote_id'] == 'EXV00000001'
     assert len(bill['versions']) == 3
     assert len(bill['sponsors']) == 1
     assert 'third title' in bill['alternate_titles']
@@ -162,12 +166,9 @@ def test_import_bill():
 def test_import_bill_with_partial_bill_vote_id():
     # test a hack added for Rhode Island where vote bill_ids are missing
     # their prefix (ie. 7033 instead of HB 7033)
-    db.metadata.insert({'_id': 'zz',
-                        'terms': [{'name': 'T1', 'sessions': ['S1', 'S2']}],
-                        '_partial_vote_bill_id': True,
-                       })
-    data = {'_type': 'bill', 'state': 'zz', 'bill_id': 'S1',
-            'chamber': 'upper', 'session': 'S1',
+    # fixture's yz state has _partial_vote_bill_id enabled
+    data = {'_type': 'bill', 'state': 'yz', 'bill_id': 'S1',
+            'chamber': 'upper', 'session': 'S1a',
             'title': 'main title',
             'sponsors': [],
             'versions': [],
@@ -178,7 +179,7 @@ def test_import_bill_with_partial_bill_vote_id():
            }
     standalone_votes = {
         # chamber, session, bill id -> vote list
-        ('upper', 'S1', '1'): [
+        ('upper', 'S1a', '1'): [
           {'motion': 'house passage', 'chamber': 'lower', 'date': None,
            'yes_count': 1, 'no_count': 0, 'other_count': 0,
            'yes_votes': [], 'no_votes': [], 'other_votes': [],
@@ -191,8 +192,9 @@ def test_import_bill_with_partial_bill_vote_id():
 
     bill = db.bills.find_one()
     assert bill['bill_id'] == 'S 1'
-    assert bill['votes'][0]['motion'] == 'house passage'
-    assert bill['votes'][0]['chamber'] == 'lower'
+    vote = db.votes.find_one()
+    assert vote['motion'] == 'house passage'
+    assert vote['chamber'] == 'lower'
 
 
 def test_fix_bill_id():
@@ -204,14 +206,16 @@ def test_fix_bill_id():
         assert bills.fix_bill_id(bill_id) == expect
 
     assert bills.fix_bill_id('PR19-0041') == 'PR 19-0041'
+    assert bills.fix_bill_id('HB12S-0041') == 'HB 12S-0041'
+    assert bills.fix_bill_id('HB 12S-0041') == 'HB 12S-0041'
     assert bills.fix_bill_id(' 999') == '999'
     assert bills.fix_bill_id('999') == '999'
 
 
 @with_setup(setup_func)
 def test_populate_current_fields():
-    db.bills.insert({'state': 'ex', 'session': 'S1', 'title': 'current term'})
-    db.bills.insert({'state': 'ex', 'session': 'S2',
+    db.bills.insert({'state': 'ex', 'session': 'S2', 'title': 'current term'})
+    db.bills.insert({'state': 'ex', 'session': 'Special2',
                      'title': 'current everything'})
     db.bills.insert({'state': 'ex', 'session': 'S0', 'title': 'not current'})
 
