@@ -1,18 +1,18 @@
 from nose.tools import with_setup
 
-from billy import db
+from billy.core import db
 from billy.importers import committees
 from billy.importers import names
 
+from .. import fixtures
+
 
 def setup_func():
-    db.metadata.drop()
     db.legislators.drop()
     db.committees.drop()
     names.__matchers = {}
 
-    db.metadata.insert({'_id': 'ex',
-                        'terms': [{'name': 'T1', 'sessions': ['S1']}]})
+    fixtures.load_metadata()
 
     leg_a = {'full_name': 'Richard Feynman', 'leg_id': 'EXL000001',
              '_id': 'EXL000001',
@@ -113,8 +113,8 @@ def test_import_committee():
     committee = {'_type': 'committee', 'state': 'ex',
                  'chamber': 'joint', 'committee': 'Reptilian Task Force',
                  'members': [
-                     {'name': 'Richard Feynman'},
-                     {'name': 'A. Einstein'},
+                     {'name': 'Richard Feynman', 'role': 'Vice-Chair'},
+                     {'name': 'A. Einstein', 'role': 'Chair'},
                  ]
                 }
 
@@ -134,4 +134,6 @@ def test_import_committee():
                                 'chamber': 'joint',
                                 'state': 'ex',
                                 'type': 'committee member',
-                                'committee': 'Reptilian Task Force'}
+                                'committee': 'Reptilian Task Force',
+                                'position': 'Vice-Chair'
+                               }
