@@ -11,7 +11,7 @@ urlpatterns = patterns('billy.web.admin.views',
     url(r'^(?P<abbr>[a-z]{2})/remove_exception/(?P<obj>.+)/$',
         'quality_exception_remove', name='quality_exception_remove'),
 
-    # Subject stuff
+    # subjects
     url(r'^(?P<abbr>[a-z]{2})/subjects/$', 'subjects',
         name='admin_subjects'),
     url(r'^(?P<abbr>[a-z]{2})/subjects-commit/$', 'subjects_commit',
@@ -19,19 +19,17 @@ urlpatterns = patterns('billy.web.admin.views',
     url(r'^(?P<abbr>[a-z]{2})/subjects-remove/(?P<id>.+)/$', 'subjects_remove',
         name='admin_subjects_remove'),
 
-    # Leg ID stuff
-    url(r'^(?P<abbr>[a-z]{2})/leg_ids/$', 'leg_ids',
-        name='admin_leg_ids'),
-    url(r'^(?P<abbr>[a-z]{2})/leg_ids-commit/$', 'leg_ids_commit',
-        name='admin_leg_ids_commit'),
-    url(r'^(?P<abbr>[a-z]{2})/leg_ids-remove/(?P<id>.+)/$', 'leg_ids_remove',
-        name='admin_leg_ids_remove'),
+    # matching
+    url(r'^(?P<abbr>[a-z]{2})/name-matching/$', 'matching.edit',
+        name='admin_matching'),
+    url(r'^(?P<abbr>[a-z]{2})/matching-commit/$', 'matching.commit',
+        name='admin_matching_commit'),
+    url(r'^(?P<abbr>[a-z]{2})/matching-remove/(?P<id>.+)/$', 'matching.remove',
+        name='admin_matching_remove'),
 
 
     # admin overview pages
     url(r'^(?P<abbr>[a-z]{2})/$', 'overview', name='admin_overview'),
-    url(r'^(?P<abbr>[a-z]{2})/metadata/$', 'metadata_json',
-        name='metadata_json'),
 
     # committees
     url(r'^(?P<abbr>[a-z]{2})/committees/$', 'committees',
@@ -39,14 +37,11 @@ urlpatterns = patterns('billy.web.admin.views',
     url(r'^delete_committees/$', 'delete_committees',
         name='delete_committees'),
 
-    # legislator list
+    # legislators
     url(r'^(?P<abbr>[a-z]{2})/legislators/$', 'legislators',
         name='admin_legislators'),
-    url(r'^legislators/(?P<id>\w+)/$', 'legislator', name='admin_legislator'),
     url(r'^legislators/(?P<id>\w+)/retire/$', 'retire_legislator',
         name='retire_legislator'),
-
-    # Edit stuff
     url(r'^legislators-edit/(?P<id>\w+)/$', 'legislator_edit',
             name='admin_legislator_edit'),
     url(r'^legislators-edit-commit/$', 'legislator_edit_commit',
@@ -55,13 +50,7 @@ urlpatterns = patterns('billy.web.admin.views',
 
     # bills
     url(r'^(?P<abbr>[a-z]{2})/bills/$', 'bills', name='admin_bills'),
-    url(r'^(?P<abbr>[a-z]{2})/bills/random/$', 'random_bill',
-        name='random_bill'),
     url(r'^(?P<abbr>[a-z]{2})/bills/list/$', 'bill_list', name='bill_list'),
-    url(r'^(?P<abbr>[a-z]{2})/bills/(?P<billy_id>\w+)/$', 'bill',
-        name='admin_bill_by_id'),
-    url(r'^(?P<abbr>[a-z]{2})/bills/(?P<session>.+)/(?P<id>.*)/$', 'bill',
-        name='admin_bill'),
 
     url(r'^(?P<abbr>[a-z]{2})/bad_vote_list/$', 'bad_vote_list',
         name='bad_vote_list'),
@@ -74,6 +63,8 @@ urlpatterns = patterns('billy.web.admin.views',
         name='other_actions'),
     url(r'^(?P<abbr>[a-z]{2})/duplicate_versions/$', 'duplicate_versions',
         name='duplicate_versions'),
+    url(r'^(?P<abbr>[a-z]{2})/progress_meter_gaps/$', 'progress_meter_gaps',
+        name='progress_meter_gaps'),
 
     # Summary urls.
     url(r'^(?P<abbr>[a-z]{2})/summary/(?P<session>[^/]+)$', 'summary_index',
