@@ -7,9 +7,9 @@ from collections import defaultdict
 
 from django.http import HttpResponse
 
-from billy import db
+from billy.core import db
 from billy.models import Bill
-from billy.conf import settings
+from billy.core import settings
 from billy.utils import find_bill, parse_param_dt
 
 import pymongo
@@ -25,7 +25,7 @@ _chamber_aliases = {
 }
 
 
-_lower_fields = ('state',)
+_lower_fields = (settings.LEVEL_FIELD,)
 
 
 def _build_mongo_filter(request, keys, icase=True):
@@ -69,11 +69,16 @@ def _build_field_list(request, default_fields=None):
         return default_fields
     else:
         d = dict(zip(fields.split(','), itertools.repeat(1)))
-        d['_id'] = d.pop('id', 0)
+        d['_id'] = d.pop('id', 1)
         d['_type'] = 1
         return d
 
 
+def _get_vote_fields(fields):
+    return [field.replace('votes.', '', 1) for field in fields or [] if
+            field.startswith('votes.')] or None
+
+
 class BillyHandlerMetaClass(HandlerMetaClass):
     """
     Returns 404 if Handler result is None.
@@ -146,7 +151,15 @@ class BillHandler(BillyHandler):
                      'bill_id': bill_id}
             if chamber:
                 query['chamber'] = chamber.lower()
-        return find_bill(query, fields=_build_field_list(request))
+        fields = _build_field_list(request)
+        bill = find_bill(query, fields=fields)
+        vote_fields = _get_vote_fields(fields)
+        # include votes if no fields are specified, if it is specified, or
+        # if subfields are specified
+        if not fields or 'votes' in fields or vote_fields:
+            bill['votes'] = list(db.votes.find({'bill_id': bill['_id']},
+                                          fields=vote_fields))
+        return bill
 
 
 class BillSearchHandler(BillyHandler):
@@ -160,9 +173,9 @@ class BillSearchHandler(BillyHandler):
         bill_fields = _build_field_list(request, bill_fields)
 
         # normal mongo search logic
-        base_fields = _build_mongo_filter(request, ('state', 'chamber',
-                                                    'subjects', 'bill_id',
-                                                    'bill_id__in'))
+        base_fields = _build_mongo_filter(request, (settings.LEVEL_FIELD,
+                                                    'chamber', 'subjects',
+                                                    'bill_id', 'bill_id__in'))
 
         # process extra attributes
         query = request.GET.get('q')
@@ -210,7 +223,24 @@ class BillSearchHandler(BillyHandler):
         elif sort == 'last_action':
             query = query.sort([('action_dates.last', -1)])
 
-        return list(query)
+        # attach votes if necessary
+        bills = list(query)
+        bill_ids = [bill['_id'] for bill in bills]
+        vote_fields = _get_vote_fields(bill_fields)
+        if 'votes' in bill_fields or vote_fields:
+            # add bill_id to vote_fields for relating back
+            votes = list(db.votes.find({'bill_id': {'$in': bill_ids}},
+                                       fields=vote_fields + ['bill_id']))
+            votes_by_bill = defaultdict(list)
+            for vote in votes:
+                votes_by_bill[vote['bill_id']].append(vote)
+                # remove bill_id unless they really requested it
+                if 'bill_id' not in vote_fields:
+                    vote.pop('bill_id')
+            for bill in bills:
+                bill['votes'] = votes_by_bill[bill['_id']]
+
+        return bills
 
 
 class LegislatorHandler(BillyHandler):
@@ -225,8 +255,8 @@ class LegislatorSearchHandler(BillyHandler):
         # replace with request's fields if they exist
         legislator_fields = _build_field_list(request, legislator_fields)
 
-        _filter = _build_mongo_filter(request, ('state', 'first_name',
-                                                'last_name'))
+        _filter = _build_mongo_filter(request, (settings.LEVEL_FIELD,
+                                                'first_name', 'last_name'))
         elemMatch = _build_mongo_filter(request, ('chamber', 'term',
                                                   'district', 'party'))
         if elemMatch:
@@ -256,7 +286,8 @@ class CommitteeSearchHandler(BillyHandler):
         committee_fields = _build_field_list(request, committee_fields)
 
         _filter = _build_mongo_filter(request, ('committee', 'subcommittee',
-                                                'chamber', 'state'))
+                                                'chamber',
+                                                settings.LEVEL_FIELD))
         return list(db.committees.find(_filter, committee_fields))
 
 
@@ -270,7 +301,7 @@ class EventsHandler(BillyHandler):
 
         spec = {}
 
-        for key in ('state', 'type'):
+        for key in (settings.LEVEL_FIELD, 'type'):
             value = request.GET.get(key)
             if not value:
                 continue
@@ -348,7 +379,7 @@ class LegislatorGeoHandler(BillyHandler):
         boundary_mapping = {}
 
         for dist in resp['objects']:
-            state = dist['name'][0:2].lower()
+            abbr = dist['name'][0:2].lower()
             chamber = {'/1.0/boundary-set/sldu/': 'upper',
                        '/1.0/boundary-set/sldl/': 'lower'}[dist['set']]
             census_name = dist['slug']
@@ -358,10 +389,10 @@ class LegislatorGeoHandler(BillyHandler):
                                            'boundary_id': census_name})
             count = districts.count()
             if count:
-                filters.append({'state': state,
+                filters.append({settings.LEVEL_FIELD: abbr,
                                 'district': districts[0]['name'],
                                 'chamber': chamber})
-                boundary_mapping[(state, districts[0]['name'],
+                boundary_mapping[(abbr, districts[0]['name'],
                                   chamber)] = census_name
 
         if not filters:
@@ -370,7 +401,7 @@ class LegislatorGeoHandler(BillyHandler):
         legislators = list(db.legislators.find({'$or': filters},
                                                _build_field_list(request)))
         for leg in legislators:
-            leg['boundary_id'] = boundary_mapping[(leg['state'],
+            leg['boundary_id'] = boundary_mapping[(leg[settings.LEVEL_FIELD],
                                                    leg['district'],
                                                    leg['chamber'])]
         return legislators
@@ -386,7 +417,7 @@ class DistrictHandler(BillyHandler):
         districts = list(db.districts.find(filter))
 
         # change leg filter
-        filter['state'] = filter.pop('abbr')
+        filter[settings.LEVEL_FIELD] = filter.pop('abbr')
         filter['active'] = True
         legislators = db.legislators.find(filter, fields={'_id': 0,
                                                           'leg_id': 1,
@@ -427,15 +458,23 @@ class BoundaryHandler(BillyHandler):
             for coord_set in shape:
                 all_lon.extend(c[0] for c in coord_set)
                 all_lat.extend(c[1] for c in coord_set)
-        lon_delta = abs(max(all_lon) - min(all_lon))
-        lat_delta = abs(max(all_lat) - min(all_lat))
+
+        min_lat = min(all_lat)
+        min_lon = min(all_lon)
+        max_lat = max(all_lat)
+        max_lon = max(all_lon)
+
+        lon_delta = abs(max_lon - min_lon)
+        lat_delta = abs(max_lat - min_lat)
 
         region = {'center_lon': centroid[0], 'center_lat': centroid[1],
                   'lon_delta': lon_delta, 'lat_delta': lat_delta,
                  }
+        bbox = [[min_lat, min_lon], [max_lat, max_lon]]
 
         district = db.districts.find_one({'boundary_id': boundary_id})
         district['shape'] = data['simple_shape']['coordinates']
         district['region'] = region
+        district['bbox'] = bbox
 
         return district
