@@ -16,7 +16,7 @@ import pymongo
 
 from billy.utils import popularity
 from billy.models import db, Metadata, DoesNotExist
-from billy.conf import settings as billy_settings
+from billy.core import settings as billy_settings
 
 from .utils import templatename, mongo_fields
 
@@ -119,14 +119,17 @@ def legislator(request, abbr, _id, slug=None):
         abbr,
         billy_settings.API_KEY
     )
-    f = urllib2.urlopen(qurl)
-    districts = json.load(f)
-    district_id = None
-    for district in districts:
-        legs = [x['leg_id'] for x in district['legislators']]
-        if legislator['leg_id'] in legs:
-            district_id = district['boundary_id']
-            break
+    try:
+        f = urllib2.urlopen(qurl)
+        districts = json.load(f)
+        district_id = None
+        for district in districts:
+            legs = [x['leg_id'] for x in district['legislators']]
+            if legislator['leg_id'] in legs:
+                district_id = district['boundary_id']
+                break
+    except urllib2.URLError:
+        district_id = None
 
     sponsored_bills = legislator.sponsored_bills(
         limit=5, sort=[('action_dates.first', pymongo.DESCENDING)])
